@@ -5,6 +5,7 @@ import (
 	"os"
 	"path/filepath"
 
+	internal "github.com/danielmiessler/fabric/cmd/generate_changelog/internal"
 	"github.com/danielmiessler/fabric/cmd/generate_changelog/internal/changelog"
 	"github.com/danielmiessler/fabric/cmd/generate_changelog/internal/config"
 	"github.com/joho/godotenv"
@@ -42,6 +43,7 @@ func init() {
 	rootCmd.Flags().StringVar(&cfg.IncomingDir, "incoming-dir", "./cmd/generate_changelog/incoming", "Directory for incoming PR files")
 	rootCmd.Flags().BoolVar(&cfg.Push, "push", false, "Enable automatic git push after creating an incoming entry")
 	rootCmd.Flags().BoolVar(&cfg.SyncDB, "sync-db", false, "Synchronize and validate database integrity with git history and GitHub PRs")
+	rootCmd.Flags().StringVar(&cfg.Release, "release", "", "Update GitHub release description with AI summary for version (e.g., v1.2.3)")
 }
 
 func run(cmd *cobra.Command, args []string) error {
@@ -49,6 +51,10 @@ func run(cmd *cobra.Command, args []string) error {
 		return fmt.Errorf("--incoming-pr and --process-prs are mutually exclusive flags")
 	}
 
+	if cfg.Release != "" && (cfg.IncomingPR > 0 || cfg.ProcessPRsVersion != "" || cfg.SyncDB) {
+		return fmt.Errorf("--release cannot be used with other processing flags")
+	}
+
 	if cfg.GitHubToken == "" {
 		cfg.GitHubToken = os.Getenv("GITHUB_TOKEN")
 	}
@@ -70,6 +76,15 @@ func run(cmd *cobra.Command, args []string) error {
 		return generator.SyncDatabase()
 	}
 
+	if cfg.Release != "" {
+		releaseManager, err := internal.NewReleaseManager(cfg)
+		if err != nil {
+			return fmt.Errorf("failed to create release manager: %w", err)
+		}
+		defer releaseManager.Close()
+		return releaseManager.UpdateReleaseDescription(cfg.Release)
+	}
+
 	output, err := generator.Generate()
 	if err != nil {
 		return fmt.Errorf("failed to generate changelog: %w", err)
