@@ -86,6 +86,9 @@ type Flags struct {
 	SuppressThink                   bool              `long:"suppress-think" yaml:"suppressThink" description:"Suppress text enclosed in thinking tags"`
 	ThinkStartTag                   string            `long:"think-start-tag" yaml:"thinkStartTag" description:"Start tag for thinking sections" default:"<think>"`
 	ThinkEndTag                     string            `long:"think-end-tag" yaml:"thinkEndTag" description:"End tag for thinking sections" default:"</think>"`
+	DisableResponsesAPI             bool              `long:"disable-responses-api" yaml:"disableResponsesAPI" description:"Disable OpenAI Responses API (default: false)"`
+	Voice                           string            `long:"voice" yaml:"voice" description:"TTS voice name for supported models (e.g., Kore, Charon, Puck)" default:"Kore"`
+	ListGeminiVoices                bool              `long:"list-gemini-voices" description:"List all available Gemini TTS voices"`
 }
 
 var debug = false
@@ -102,26 +105,34 @@ func Init() (ret *Flags, err error) {
 	usedFlags := make(map[string]bool)
 	yamlArgsScan := os.Args[1:]
 
-	// Get list of fields that have yaml tags, could be in yaml config
-	yamlFields := make(map[string]bool)
+	// Create mapping from flag names (both short and long) to yaml tag names
+	flagToYamlTag := make(map[string]string)
 	t := reflect.TypeOf(Flags{})
 	for i := 0; i < t.NumField(); i++ {
-		if yamlTag := t.Field(i).Tag.Get("yaml"); yamlTag != "" {
-			yamlFields[yamlTag] = true
-			//Debugf("Found yaml-configured field: %s\n", yamlTag)
+		field := t.Field(i)
+		yamlTag := field.Tag.Get("yaml")
+		if yamlTag != "" {
+			longTag := field.Tag.Get("long")
+			shortTag := field.Tag.Get("short")
+			if longTag != "" {
+				flagToYamlTag[longTag] = yamlTag
+				Debugf("Mapped long flag %s to yaml tag %s\n", longTag, yamlTag)
+			}
+			if shortTag != "" {
+				flagToYamlTag[shortTag] = yamlTag
+				Debugf("Mapped short flag %s to yaml tag %s\n", shortTag, yamlTag)
+			}
 		}
 	}
 
 	// Scan args for that are provided by cli and might be in yaml
 	for _, arg := range yamlArgsScan {
-		if strings.HasPrefix(arg, "--") {
-			flag := strings.TrimPrefix(arg, "--")
-			if i := strings.Index(flag, "="); i > 0 {
-				flag = flag[:i]
-			}
-			if yamlFields[flag] {
-				usedFlags[flag] = true
-				Debugf("CLI flag used: %s\n", flag)
+		flag := extractFlag(arg)
+
+		if flag != "" {
+			if yamlTag, exists := flagToYamlTag[flag]; exists {
+				usedFlags[yamlTag] = true
+				Debugf("CLI flag used: %s (yaml: %s)\n", flag, yamlTag)
 			}
 		}
 	}
@@ -134,6 +145,16 @@ func Init() (ret *Flags, err error) {
 		return
 	}
 
+	// Check to see if a ~/.config/fabric/config.yaml config file exists (only when user didn't specify a config)
+	if ret.Config == "" {
+		// Default to ~/.config/fabric/config.yaml if no config specified
+		if defaultConfigPath, err := util.GetDefaultConfigPath(); err == nil && defaultConfigPath != "" {
+			ret.Config = defaultConfigPath
+		} else if err != nil {
+			Debugf("Could not determine default config path: %v\n", err)
+		}
+	}
+
 	// If config specified, load and apply YAML for unused flags
 	if ret.Config != "" {
 		var yamlFlags *Flags
@@ -168,7 +189,6 @@ func Init() (ret *Flags, err error) {
 		}
 	}
 
-	// Handle stdin and messages
 	// Handle stdin and messages
 	info, _ := os.Stdin.Stat()
 	pipedToStdin := (info.Mode() & os.ModeCharDevice) == 0
@@ -188,6 +208,22 @@ func Init() (ret *Flags, err error) {
 	return
 }
 
+func extractFlag(arg string) string {
+	var flag string
+	if strings.HasPrefix(arg, "--") {
+		flag = strings.TrimPrefix(arg, "--")
+		if i := strings.Index(flag, "="); i > 0 {
+			flag = flag[:i]
+		}
+	} else if strings.HasPrefix(arg, "-") && len(arg) > 1 {
+		flag = strings.TrimPrefix(arg, "-")
+		if i := strings.Index(flag, "="); i > 0 {
+			flag = flag[:i]
+		}
+	}
+	return flag
+}
+
 func assignWithConversion(targetField, sourceField reflect.Value) error {
 	// Handle string source values
 	if sourceField.Kind() == reflect.String {
@@ -407,6 +443,7 @@ func (o *Flags) BuildChatOptions() (ret *domain.ChatOptions, err error) {
 		SuppressThink:      o.SuppressThink,
 		ThinkStartTag:      startTag,
 		ThinkEndTag:        endTag,
+		Voice:              o.Voice,
 	}
 	return
 }
